@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::Ad;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -62,16 +65,21 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 EditorialStatus
 
-=over 8
+Gets/sets EditorialStatus (AdEditorialStatus)
 
-EditorialStatus (AdEditorialStatus)
-Id (long)
-Status (AdStatus)
-Type (AdType)
+=head2 Id
 
-=back
+Gets/sets Id (long)
+
+=head2 Status
+
+Gets/sets Status (AdStatus)
+
+=head2 Type
+
+Gets/sets Type (AdType)
 
 =cut
 
