@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CampaignManagementService::KeywordQuality;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -64,17 +67,25 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 BroadMatchQualityScore
 
-=over 8
+Gets/sets BroadMatchQualityScore (KeywordQualityDetail)
 
-BroadMatchQualityScore (KeywordQualityDetail)
-ContentMatchQualityScore (KeywordQualityDetail)
-ExactMatchQualityScore (KeywordQualityDetail)
-KeywordId (long)
-PhraseMatchQualityScore (KeywordQualityDetail)
+=head2 ContentMatchQualityScore
 
-=back
+Gets/sets ContentMatchQualityScore (KeywordQualityDetail)
+
+=head2 ExactMatchQualityScore
+
+Gets/sets ExactMatchQualityScore (KeywordQualityDetail)
+
+=head2 KeywordId
+
+Gets/sets KeywordId (long)
+
+=head2 PhraseMatchQualityScore
+
+Gets/sets PhraseMatchQualityScore (KeywordQualityDetail)
 
 =cut
 
