@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::CustomerManagementService::AdCenterCustomer;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -64,17 +67,25 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 CustomerAddress
 
-=over 8
+Gets/sets CustomerAddress (AdCenterAddress)
 
-CustomerAddress (AdCenterAddress)
-CustomerId (int)
-CustomerName (string)
-IndustryId (Industry)
-MarketId (Market)
+=head2 CustomerId
 
-=back
+Gets/sets CustomerId (int)
+
+=head2 CustomerName
+
+Gets/sets CustomerName (string)
+
+=head2 IndustryId
+
+Gets/sets IndustryId (Industry)
+
+=head2 MarketId
+
+Gets/sets MarketId (Market)
 
 =cut
 
