@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::NotificationManagementService::ApiUserAuthHeader;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -60,15 +63,17 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Password
 
-=over 8
+Gets/sets Password (string)
 
-Password (string)
-UserAccessKey (string)
-UserName (string)
+=head2 UserAccessKey
 
-=back
+Gets/sets UserAccessKey (string)
+
+=head2 UserName
+
+Gets/sets UserName (string)
 
 =cut
 
