@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::NotificationManagementService::CreditCardNotification;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -66,24 +69,35 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 =head1 METHODS
 
+Remark: Inherited methods are not listed.
+
 =head2 new
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 AccountId
 
-=over 8
+Gets/sets AccountId (int)
 
-AccountId (int)
-AccountNumber (string)
-CreditCardExpirationDate (dateTime)
-CreditCardLastFour (string)
-CreditCardTypeName (string)
-NoticeNumber (int)
+=head2 AccountNumber
 
-Inherited attributes are not listed.
+Gets/sets AccountNumber (string)
 
-=back
+=head2 CreditCardExpirationDate
+
+Gets/sets CreditCardExpirationDate (dateTime)
+
+=head2 CreditCardLastFour
+
+Gets/sets CreditCardLastFour (string)
+
+=head2 CreditCardTypeName
+
+Gets/sets CreditCardTypeName (string)
+
+=head2 NoticeNumber
+
+Gets/sets NoticeNumber (int)
 
 =cut
 
