@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::ReportingService::BudgetSummaryReportRequest;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -60,21 +63,23 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 =head1 METHODS
 
+Remark: Inherited methods are not listed.
+
 =head2 new
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 Columns
 
-=over 8
+Gets/sets Columns (ArrayOfBudgetSummaryReportColumn)
 
-Columns (ArrayOfBudgetSummaryReportColumn)
-Scope (AccountReportScope)
-Time (BudgetSummaryReportTime)
+=head2 Scope
 
-Inherited attributes are not listed.
+Gets/sets Scope (AccountReportScope)
 
-=back
+=head2 Time
+
+Gets/sets Time (BudgetSummaryReportTime)
 
 =cut
 
