@@ -1,4 +1,7 @@
 package Microsoft::AdCenter::ReportingService::SitePerformanceReportFilter;
+# Copyright (C) 2010 Xerxes Tsang
+# This program is free software; you can redistribute it and/or modify it
+# under the terms of Perl Artistic License.
 
 use strict;
 use warnings;
@@ -64,17 +67,25 @@ See L<http://msdn.microsoft.com/en-US/library/ee730327%28v=MSADS.60%29.aspx> for
 
 Creates a new instance
 
-=head2 get/set methods
+=head2 AdDistribution
 
-=over 8
+Gets/sets AdDistribution (AdDistributionReportFilter)
 
-AdDistribution (AdDistributionReportFilter)
-AdType (AdTypeReportFilter)
-DeliveredMatchType (DeliveredMatchTypeReportFilter)
-LanguageAndRegion (LanguageAndRegionReportFilter)
-SiteIds (ArrayOflong)
+=head2 AdType
 
-=back
+Gets/sets AdType (AdTypeReportFilter)
+
+=head2 DeliveredMatchType
+
+Gets/sets DeliveredMatchType (DeliveredMatchTypeReportFilter)
+
+=head2 LanguageAndRegion
+
+Gets/sets LanguageAndRegion (LanguageAndRegionReportFilter)
+
+=head2 SiteIds
+
+Gets/sets SiteIds (ArrayOflong)
 
 =cut
 
